@@ -1,6 +1,7 @@
 from sly import Parser
 from mindsdb_sql_parser.ast import *
 from mindsdb_sql_parser.ast.drop import DropDatabase, DropView
+from mindsdb_sql_parser.ast.mindsdb.alter_database import AlterDatabase
 from mindsdb_sql_parser.ast.mindsdb.agents import CreateAgent, DropAgent, UpdateAgent
 from mindsdb_sql_parser.ast.mindsdb.drop_datasource import DropDatasource
 from mindsdb_sql_parser.ast.mindsdb.drop_predictor import DropPredictor
@@ -10,13 +11,15 @@ from mindsdb_sql_parser.ast.mindsdb.create_predictor import CreatePredictor, Cre
 from mindsdb_sql_parser.ast.mindsdb.create_database import CreateDatabase
 from mindsdb_sql_parser.ast.mindsdb.create_ml_engine import CreateMLEngine
 from mindsdb_sql_parser.ast.mindsdb.create_view import CreateView
+from mindsdb_sql_parser.ast.mindsdb.alter_view import AlterView
 from mindsdb_sql_parser.ast.mindsdb.create_job import CreateJob
 from mindsdb_sql_parser.ast.mindsdb.chatbot import CreateChatBot, UpdateChatBot, DropChatBot
 from mindsdb_sql_parser.ast.mindsdb.drop_job import DropJob
 from mindsdb_sql_parser.ast.mindsdb.trigger import CreateTrigger, DropTrigger
 from mindsdb_sql_parser.ast.mindsdb.latest import Latest
 from mindsdb_sql_parser.ast.mindsdb.evaluate import Evaluate
-from mindsdb_sql_parser.ast.mindsdb.knowledge_base import CreateKnowledgeBase, DropKnowledgeBase
+from mindsdb_sql_parser.ast.mindsdb.knowledge_base import CreateKnowledgeBase, DropKnowledgeBase, \
+    CreateKnowledgeBaseIndex, DropKnowledgeBaseIndex, EvaluateKnowledgeBase
 from mindsdb_sql_parser.ast.mindsdb.skills import CreateSkill, DropSkill, UpdateSkill
 from mindsdb_sql_parser.exceptions import ParsingException
 from mindsdb_sql_parser.ast.mindsdb.retrain_predictor import RetrainPredictor
@@ -76,7 +79,9 @@ class MindsDBParser(Parser):
        'delete',
        'evaluate',
        'drop_database',
+       'alter_database',
        'drop_view',
+       'alter_view',
        'drop_table',
        'create_table',
        'create_job',
@@ -88,12 +93,15 @@ class MindsDBParser(Parser):
        'drop_trigger',
        'create_kb',
        'drop_kb',
+       'evaluate_kb',
        'create_skill',
        'drop_skill',
        'update_skill',
        'create_agent',
        'drop_agent',
-       'update_agent'
+       'update_agent',
+       'create_index',
+       'drop_index',
        )
     def query(self, p):
         return p[0]
@@ -134,10 +142,25 @@ class MindsDBParser(Parser):
             if_not_exists=if_not_exists
         )
 
+    @_('CREATE INDEX ON KNOWLEDGE_BASE identifier')
+    def create_index(self, p):
+        return CreateKnowledgeBaseIndex(name=p.identifier)
+
+    @_('DROP INDEX ON KNOWLEDGE_BASE identifier')
+    def  drop_index(self, p):
+        return DropKnowledgeBaseIndex(name=p.identifier)
+
     @_('DROP KNOWLEDGE_BASE if_exists_or_empty identifier')
     def drop_kb(self, p):
         return DropKnowledgeBase(name=p.identifier, if_exists=p.if_exists_or_empty)
 
+    @_('EVALUATE KNOWLEDGE_BASE identifier USING kw_parameter_list')
+    def evaluate_kb(self, p):
+        return EvaluateKnowledgeBase(
+            name=p.identifier,
+            params={k.lower(): v for k, v in p.kw_parameter_list.items()}
+        )
+
     # -- Skills --
     @_('CREATE SKILL if_not_exists_or_empty identifier USING kw_parameter_list')
     def create_skill(self, p):
@@ -331,6 +354,15 @@ class MindsDBParser(Parser):
     def drop_database(self, p):
         return DropDatabase(name=p.identifier, if_exists=p.if_exists_or_empty)
 
+    # ALTER DATABASE
+    @_('ALTER DATABASE identifier kw_parameter_list')
+    def alter_database(self, p):
+        params = {k.lower(): v for k, v in p.kw_parameter_list.items()}
+        return AlterDatabase(
+            name=p.identifier,
+            altered_params=params
+        )
+
     # Transactions
 
     @_('START TRANSACTION',
@@ -679,6 +711,18 @@ class MindsDBParser(Parser):
                           query_str=query_str,
                           if_not_exists=p.if_not_exists_or_empty)
 
+    # ALTER VIEW
+    @_('ALTER VIEW identifier create_view_from_table_or_nothing AS LPAREN raw_query RPAREN',
+       'ALTER VIEW identifier create_view_from_table_or_nothing LPAREN raw_query RPAREN')
+    def alter_view(self, p):
+        query_str = tokens_to_string(p.raw_query)
+
+        return AlterView(
+            name=p.identifier,
+            from_table=p.create_view_from_table_or_nothing,
+            query_str=query_str
+        )
+
     @_('FROM identifier')
     def create_view_from_table_or_nothing(self, p):
         return p.identifier
@@ -712,6 +756,7 @@ class MindsDBParser(Parser):
     @_('id id',
        'id id DEFAULT id',
        'id id PRIMARY_KEY',
+       'id id LPAREN INTEGER RPAREN PRIMARY_KEY',
        'id id LPAREN INTEGER RPAREN',
        'id id LPAREN INTEGER COMMA INTEGER RPAREN',
        'id id LPAREN INTEGER RPAREN DEFAULT id',
